==> prestashop_1.4.0.2.zip: prestashop/modules/fianetsceau/es.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{fianetsceau}prestashop>fianetsceau_72517ac17e72188b4043e77a151920d0'] = 'FIA-NET signo de confianza';
$_MODULE['<{fianetsceau}prestashop>fianetsceau_79841d454ebed67000c0c982796c6b9d'] = 'Transforme sus visitantes en compradores haciendo que confien en su sitio Web';
$_MODULE['<{fianetsceau}prestashop>fianetsceau_f9d62663cd34b0675f1fd34a0e8da283'] = 'Por favor, introduzca su Clave Privada';
$_MODULE['<{fianetsceau}prestashop>fianetsceau_42d90cf6237830c7d1aae4c35a5211a1'] = 'Por favor, introduzca la ID de su sitio';
$_MODULE['<{fianetsceau}prestashop>fianetsceau_c888438d14855d7d96a2724ee9c306bd'] = 'Confuguración actualizada';
$_MODULE['<{fianetsceau}prestashop>fianetsceau_f4f70727dc34561dfde1a3c529b6205c'] = 'Parámetros';
$_MODULE['<{fianetsceau}prestashop>fianetsceau_ee56be2890222bce04455a34055fd107'] = 'ID de su sitio';
$_MODULE['<{fianetsceau}prestashop>fianetsceau_f0f5fac9602d88bc27f0edf960dda8b8'] = 'Ejemplo:';
$_MODULE['<{fianetsceau}prestashop>fianetsceau_7b00d0388fa5d48b7b00e4f71e4d71d0'] = '(números solamente)';
$_MODULE['<{fianetsceau}prestashop>fianetsceau_d2560860c51f895a9871741f0805c39e'] = 'Clave privada';
$_MODULE['<{fianetsceau}prestashop>fianetsceau_15e8f5f1bb8a1c0cd63bb832412799b1'] = 'Clave privada comunicada por FIA-NET';
$_MODULE['<{fianetsceau}prestashop>fianetsceau_650be61892bf690026089544abbd9d26'] = 'Modo';
$_MODULE['<{fianetsceau}prestashop>fianetsceau_0cbc6611f5540bd0809a388dc95a615b'] = 'Test';
$_MODULE['<{fianetsceau}prestashop>fianetsceau_756d97bb256b8580d4d71ee0c547804e'] = 'Producción';
$_MODULE['<{fianetsceau}prestashop>fianetsceau_b17f3f4dcf653a5776792498a9b44d6a'] = 'Actualizar';

==> prestashop_1.4.0.9.zip: prestashop/modules/fianetsceau/es.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{fianetsceau}prestashop>fianetsceau_72517ac17e72188b4043e77a151920d0'] = 'FIA-NET signo de confianza';
$_MODULE['<{fianetsceau}prestashop>fianetsceau_79841d454ebed67000c0c982796c6b9d'] = 'Transforme sus visitantes en compradores haciendo que confien en su sitio Web';
$_MODULE['<{fianetsceau}prestashop>fianetsceau_f9d62663cd34b0675f1fd34a0e8da283'] = 'Por favor, introduzca su Clave Privada';
$_MODULE['<{fianetsceau}prestashop>fianetsceau_42d90cf6237830c7d1aae4c35a5211a1'] = 'Por favor, introduzca la ID de su sitio';
$_MODULE['<{fianetsceau}prestashop>fianetsceau_20015706a8cbd457cbb6ea3e7d5dc9b3'] = 'Parámetros actualizados con éxito';
$_MODULE['<{fianetsceau}prestashop>fianetsceau_380b4179d36bce6ca862459a43b217b5'] = 'Para conectarse, visite:';
$_MODULE['<{fianetsceau}prestashop>fianetsceau_592fcfe937f6d58f70d0918ef6373afa'] = 'Web de FIA-net';
$_MODULE['<{fianetsceau}prestashop>fianetsceau_f4f70727dc34561dfde1a3c529b6205c'] = 'Parámetros';
$_MODULE['<{fianetsceau}prestashop>fianetsceau_ee56be2890222bce04455a34055fd107'] = 'ID de su sitio';
$_MODULE['<{fianetsceau}prestashop>fianetsceau_f0f5fac9602d88bc27f0edf960dda8b8'] = 'Ejemplo:';
$_MODULE['<{fianetsceau}prestashop>fianetsceau_7b00d0388fa5d48b7b00e4f71e4d71d0'] = '(números solamente)';
$_MODULE['<{fianetsceau}prestashop>fianetsceau_d2560860c51f895a9871741f0805c39e'] = 'Clave privada';
$_MODULE['<{fianetsceau}prestashop>fianetsceau_15e8f5f1bb8a1c0cd63bb832412799b1'] = 'Clave privada comunicada por FIA-NET';
$_MODULE['<{fianetsceau}prestashop>fianetsceau_650be61892bf690026089544abbd9d26'] = 'Modo';
$_MODULE['<{fianetsceau}prestashop>fianetsceau_0cbc6611f5540bd0809a388dc95a615b'] = 'Test';
$_MODULE['<{fianetsceau}prestashop>fianetsceau_756d97bb256b8580d4d71ee0c547804e'] = 'Producción';
$_MODULE['<{fianetsceau}prestashop>fianetsceau_b17f3f4dcf653a5776792498a9b44d6a'] = 'Actualizar';
